pub(crate) fn security_from_proto(sec: &Security) -> SecurityExpand description
Compatibility-shell boundary for backend proto Security values that still
need the legacy SDK DTO before formatting through existing CLI helpers.
pub(crate) fn security_from_proto(sec: &Security) -> SecurityCompatibility-shell boundary for backend proto Security values that still
need the legacy SDK DTO before formatting through existing CLI helpers.